@@ -41,56 +41,53 @@
 	(if (not (looking-at pattern))
 	    (skip-chars-forward "^ \t\r\n")
 	  (let* ((last (match-end 0))
-		 (b1 (match-beginning 1))
-		 (e1 (match-end 1))
-		 (b2 (match-beginning 2))
-		 (e2 (match-end 2))
-		 (kind (rail-assoc (buffer-substring b1 e1) rail-product-name-alist t))
+		 (kind (rail-assoc
+			(buffer-substring (match-beginning 1) (match-end 1))
+			rail-product-name-alist t))
 		 alist-a alist-b ccode)
-	    (if (not kind)
-		(goto-char last)
-	      (setq ccode   (prin1-to-string kind)
-		    alist-a (symbol-value
-			     (intern (format "rail-additional-%s-codename-alist" ccode)))
-		    alist-b (symbol-value
-			     (intern (format "rail-%s-codename-alist" ccode))))
-	      (setq ccode (rail-assoc (rail-replace-into-iso8859-4 (buffer-substring b2 e2))
-				      (append alist-a alist-b)
-				      rail-convert-direction))
+ 	    (if (not kind)
+ 		(goto-char last)
+	      (goto-char (match-beginning 2))
+ 	      (setq ccode   (prin1-to-string kind)
+ 		    alist-a (symbol-value
+ 			     (intern (format "rail-additional-%s-codename-alist" ccode)))
+ 		    alist-b (symbol-value
+ 			     (intern (format "rail-%s-codename-alist" ccode))))
+	      (rail-replace-codename-primitive alist-a alist-b)
 	      (and pattern2
 		   (eq 'xmas kind)
-		   (eq nil ccode)
 		   (looking-at pattern2)
-		   (setq b2    (match-beginning 3)
-			 e2    (match-end 3)
-			 ccode (rail-assoc (rail-replace-into-iso8859-4
-					    (buffer-substring b2 e2))
-					   (append rail-additional-xmas-codename-alist
-						   rail-xmas-codename-alist)
-					   rail-convert-direction)))
-	      (if (not ccode)
-		  (goto-char last)
-		(goto-char b2)
-		(delete-region b2 e2)
-		(insert ccode)
-		(forward-char 1))))))
+		   (let ((b2    (match-beginning 3))
+			 (e2    (match-end 3))
+			 (ccode (rail-assoc (rail-replace-into-iso8859-4
+					     (buffer-substring b2 e2))
+					    (append rail-additional-xmas-codename-alist
+						    rail-xmas-codename-alist)
+					    rail-convert-direction)))
+		     (if (not ccode)
+			 (goto-char last)
+		       (goto-char b2)
+		       (delete-region b2 e2)
+		       (insert ccode)
+		       (forward-char 1))))))))
       (buffer-substring (point-min) (point-max)))))
 
 ;; search header
 (defun rail-user-agent-search-header (head)
   "Search header string and return region."
-  (save-excursion
-    (goto-char (point-min))
-    (and (re-search-forward (format "^%s:\\s +" head) nil t)
-	 (let ((pt (point)))
-	   (if (catch 'header-end
-		 (while (not (eobp))
-		   (forward-line 1)
-		   (or (looking-at "\\s ")
-		       (throw 'header-end t))))
-	       (progn
-		 (forward-char -1)
-		 (cons pt (point))))))))
+  (let ((case-fold-search t))
+    (save-excursion
+      (goto-char (point-min))
+      (and (re-search-forward (format "^%s:\\s +" head) nil t)
+	   (let ((pt (point)))
+	     (if (catch 'header-end
+		   (while (not (eobp))
+		     (forward-line 1)
+		     (or (looking-at "\\s ")
+			 (throw 'header-end t))))
+		 (progn
+		   (forward-char -1)
+		   (cons pt (point)))))))))
 
 ;; replace MIME-Version: header dinamically
 (defun rail-user-agent-replace-mime-version-region (beg end)
